# Table of Contents

- [managed-code](<./managed-code.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Managed Code](<./Managed-Code.md>)
  - [Overview](<./Managed-Code/Overview.md>)
  - [Features with Code Support](<./Managed-Code/Features-with-Code-Support.md>)
  - [Viewing Code Configurations](<./Managed-Code/Viewing-Code-Configurations.md>)
  - [Viewing Execution Details](<./Managed-Code/Viewing-Execution-Details.md>)
  - [Updating Code](<./Managed-Code/Updating-Code.md>)
  - [Troubleshooting](<./Managed-Code/Troubleshooting.md>)
  - [Related Information](<./Managed-Code/Related-Information.md>)
